<?php

App::uses('Component', 'Controller');

class BreadcrumbComponent extends Component
{
    /**
     * Controller object that initialised the component
     *
     * @var object
     */
    protected $controller = null;

    /**
     * array containing the links we've added
     *
     * @var array
     */
    protected $links = array();

    /**
     * array containing the text / link for a floating right item (usually back link)(
     *
     * @var array
     */
    protected $backLink = array();

    /**
     * default seperator to use. As default will be appended to the end of li element
     *
     * @var string
     */
    protected $separator = '<span class="breadcrumbs__sep"><i class="fa fa-angle-right"></i></span>';

    /**
     * Sets a reference to the calling controller from within the component.
     *
     * @see Component::initialize()
     */
    public function initialize(Controller $controller) {

        parent::initialize($controller);

        $this->controller = $controller;
    }


    /**
     * add or return the main breadcrumb links
     *
     * @param   string|null         Optional: The link text to display
     * @param   array|string|null   Optional: The actual link or route array.
     * @param   array               Optional: Link options, incase escape => false type info needs passing
     * @return  array               If both items are null, items will be returned
     */
    public function links($text = null, $url = null, $options = array())
    {
        if (is_null($text)) {

            return $this->links;
        }

        $this->links[] = array(
            'text' => $text,
            'url' => $url,
            'options' => $options
        );
    }


    /**
     * clear all the links.
     * Just sets back to empty array
     */
    public function clearLinks()
    {
        $this->links = array();
    }


    /**
     * add or return the back link
     *
     * @param   string|null         Optional: The link text to display
     * @param   array|string|null   Optional: The actual link or route array.
     * @param   array               Optional: Link options, incase escape => false type info needs passing
     * @return  array               If both items are null, items will be returned
     */
    public function backLink($text = null, $url = null, $options = array())
    {
        if (is_null($text)) {

            return $this->backLink;
        }

        $this->backLink = array(
            'text' => $text,
            'url' => $url,
            'options' => $options
        );
    }


    /**
     * add or return the separator
     *
     * @param   string|null         Optional: The string to use as a separator
     * @return  string              If item is null, separator will be returned
     */
    public function separator($text = null)
    {
        if (is_null($text)) {

            return $this->separator;
        }

        $this->separator = $text;
    }


    /**
     * Before Render callback. If we've not got the controller yet
     * set it's object and then assign all our vars to template
     */
    /**
     * Called before the Controller::beforeRender(), and before
     * the view class is loaded, and before Controller::render()
     *
     * @param Controller $controller Controller with components to beforeRender
     * @return void
     * @link http://book.cakephp.org/2.0/en/controllers/components.html#Component::beforeRender
     */
    public function beforeRender(Controller $controller) {

        if (is_null($this->controller)) {

            $this->controller = $controller;
        }

        $this->setToView();
    }


    /**
     * build an array and assign data to view
     *
     */
    protected function setToView()
    {
        $this->controller->set(
            'breadcrumbs',
            array(
                'links' => $this->links,
                'backLink' => $this->backLink,
                'separator' => $this->separator
            )
        );
    }

}
